@@ -10,7 +10,7 @@ from tortoise.backends.base.executor import BaseExecutor
 
 class AsyncpgExecutor(BaseExecutor):
     EXPLAIN_PREFIX = "EXPLAIN (FORMAT JSON, VERBOSE)"
-    DB_NATIVE = BaseExecutor.DB_NATIVE | {uuid.UUID}
+    DB_NATIVE = BaseExecutor.DB_NATIVE | {bool, uuid.UUID}
 
     def Parameter(self, pos: int) -> Parameter:
         return Parameter("$%d" % (pos + 1,))
