@@ -76,6 +76,13 @@ class IntField(Field, int):
             kwargs["generated"] = bool(kwargs.get("generated", True))
         super().__init__(pk=pk, **kwargs)
 
+    @property
+    def constraints(self) -> dict:
+        return {
+            "ge": 1 if self.generated else -2147483648,
+            "le": 2147483647,
+        }
+
     class _db_postgres:
         GENERATED_SQL = "SERIAL NOT NULL PRIMARY KEY"
 
@@ -102,6 +109,13 @@ class BigIntField(Field, int):
             kwargs["generated"] = bool(kwargs.get("generated", True))
         super().__init__(pk=pk, **kwargs)
 
+    @property
+    def constraints(self) -> dict:
+        return {
+            "ge": 1 if self.generated else -9223372036854775808,
+            "le": 9223372036854775807,
+        }
+
     class _db_postgres:
         GENERATED_SQL = "BIGSERIAL NOT NULL PRIMARY KEY"
 
@@ -128,6 +142,13 @@ class SmallIntField(Field, int):
             kwargs["generated"] = bool(kwargs.get("generated", True))
         super().__init__(pk=pk, **kwargs)
 
+    @property
+    def constraints(self) -> dict:
+        return {
+            "ge": 1 if self.generated else -32768,
+            "le": 32767,
+        }
+
     class _db_postgres:
         GENERATED_SQL = "SMALLSERIAL NOT NULL PRIMARY KEY"
 
@@ -154,6 +175,12 @@ class CharField(Field, str):  # type: ignore
         self.max_length = int(max_length)
         super().__init__(**kwargs)
 
+    @property
+    def constraints(self) -> dict:
+        return {
+            "max_length": self.max_length,
+        }
+
     @property
     def SQL_TYPE(self) -> str:  # type: ignore
         return f"VARCHAR({self.max_length})"
@@ -286,6 +313,13 @@ class DatetimeField(Field, datetime.datetime):
                 return value
         return value
 
+    @property
+    def constraints(self) -> dict:
+        data = {}
+        if self.auto_now_add:
+            data["readOnly"] = True
+        return data
+
 
 class DateField(Field, datetime.date):
     """
