@@ -75,7 +75,7 @@ class QuerySetSingle(Protocol[T_co]):
 
 
 class AwaitableQuery(Generic[MODEL]):
-    __slots__ = ("_joined_tables", "query", "model", "_db", "capabilities")
+    __slots__ = ("_joined_tables", "query", "model", "_db", "capabilities", "_annotations")
 
     def __init__(self, model: Type[MODEL]) -> None:
         self._joined_tables: List[Table] = []
@@ -83,6 +83,7 @@ class AwaitableQuery(Generic[MODEL]):
         self.query: QueryBuilder = QUERY
         self._db: BaseDBAsyncClient = None  # type: ignore
         self.capabilities: Capabilities = model._meta.db.capabilities
+        self._annotations: Dict[str, Function] = {}
 
     def resolve_filters(
         self,
@@ -99,6 +100,8 @@ class AwaitableQuery(Generic[MODEL]):
         :param annotations: Extra annotations to add.
         :param custom_filters:
         """
+        has_aggregate = self._resolve_annotate()
+
         modifier = QueryModifier()
         for node in q_objects:
             modifier &= node.resolve(model, annotations, custom_filters, model._meta.basetable)
@@ -112,6 +115,11 @@ class AwaitableQuery(Generic[MODEL]):
         self.query._wheres = where_criterion
         self.query._havings = having_criterion
 
+        if has_aggregate and (self._joined_tables or having_criterion):
+            self.query = self.query.groupby(
+                self.model._meta.basetable[self.model._meta.db_pk_field]
+            )
+
     def _join_table_by_field(
         self, table: Table, related_field_name: str, related_field: RelationalField
     ) -> Table:
@@ -176,11 +184,12 @@ class AwaitableQuery(Generic[MODEL]):
                 annotation_info = annotation.resolve(self.model, table)
                 self.query = self.query.orderby(annotation_info["field"], order=ordering[1])
             else:
-                field_object = self.model._meta.fields_map.get(field_name)
+                field_object = model._meta.fields_map.get(field_name)
+
                 if not field_object:
-                    raise FieldError(f"Unknown field {field_name} for model {self.model.__name__}")
+                    raise FieldError(f"Unknown field {field_name} for model {model.__name__}")
                 field_name = field_object.source_field or field_name
-                field = getattr(table, field_name)
+                field = table[field_name]
 
                 func = field_object.get_for_dialect(
                     model._meta.db.capabilities.dialect, "function_cast"
@@ -190,6 +199,22 @@ class AwaitableQuery(Generic[MODEL]):
 
                 self.query = self.query.orderby(field, order=ordering[1])
 
+    def _resolve_annotate(self) -> bool:
+        if not self._annotations:
+            return False
+
+        table = self.model._meta.basetable
+        annotation_info = {}
+        for key, annotation in self._annotations.items():
+            annotation_info[key] = annotation.resolve(self.model, table)
+
+        for key, info in annotation_info.items():
+            for join in info["joins"]:
+                self._join_table_by_field(*join)
+            self.query._select_other(info["field"].as_(key))
+
+        return any(info["field"].is_aggregate for info in annotation_info.values())
+
     def _make_query(self) -> None:
         raise NotImplementedError()  # pragma: nocoverage
 
@@ -211,7 +236,6 @@ class QuerySet(AwaitableQuery[MODEL]):
         "_orderings",
         "_q_objects",
         "_distinct",
-        "_annotations",
         "_having",
         "_custom_filters",
     )
@@ -229,7 +253,6 @@ class QuerySet(AwaitableQuery[MODEL]):
         self._orderings: List[Tuple[str, Any]] = []
         self._q_objects: List[Q] = []
         self._distinct: bool = False
-        self._annotations: Dict[str, Function] = {}
         self._having: Dict[str, Any] = {}
         self._custom_filters: Dict[str, dict] = {}
 
@@ -392,7 +415,8 @@ class QuerySet(AwaitableQuery[MODEL]):
                 field
                 for field in self.model._meta.fields_map.keys()
                 if field in self.model._meta.db_fields
-            ],
+            ]
+            + list(self._annotations.keys()),
             distinct=self._distinct,
             limit=self._limit,
             offset=self._offset,
@@ -423,11 +447,13 @@ class QuerySet(AwaitableQuery[MODEL]):
                     raise FieldError(f"Duplicate key {return_as}")
                 fields_for_select[return_as] = field
         else:
-            fields_for_select = {
-                field: field
+            _fields = [
+                field
                 for field in self.model._meta.fields_map.keys()
                 if field in self.model._meta.db_fields
-            }
+            ] + list(self._annotations.keys())
+
+            fields_for_select = {field: field for field in _fields}
 
         return ValuesQuery(
             db=self._db,
@@ -585,26 +611,8 @@ class QuerySet(AwaitableQuery[MODEL]):
         queryset._db = _db
         return queryset
 
-    def _resolve_annotate(self) -> None:
-        if not self._annotations:
-            return
-
-        table = self.model._meta.basetable
-        annotation_info = {}
-        for key, annotation in self._annotations.items():
-            annotation_info[key] = annotation.resolve(self.model, table)
-
-        if any(info["field"].is_aggregate for info in annotation_info.values()):
-            self.query = self.query.groupby(table[self.model._meta.db_pk_field])
-
-        for key, info in annotation_info.items():
-            for join in info["joins"]:
-                self._join_table_by_field(*join)
-            self.query._select_other(info["field"].as_(key))
-
     def _make_query(self) -> None:
         self.query = copy(self.model._meta.basequery_all_fields)
-        self._resolve_annotate()
         self.resolve_filters(
             model=self.model,
             q_objects=self._q_objects,
@@ -839,7 +847,7 @@ class FieldSelectQuery(AwaitableQuery):
         table = self.model._meta.basetable
         if field in self.model._meta.fields_db_projection:
             db_field = self.model._meta.fields_db_projection[field]
-            self.query._select_field(getattr(table, db_field).as_(return_as))
+            self.query._select_field(table[db_field].as_(return_as))
             return
 
         if field in self.model._meta.fetch_fields:
@@ -849,9 +857,7 @@ class FieldSelectQuery(AwaitableQuery):
             )
 
         if field in self.annotations:
-            annotation = self.annotations[field]
-            annotation_info = annotation.resolve(self.model, table)
-            self.query._select_other(annotation_info["field"].as_(return_as))
+            self._annotations[return_as] = self.annotations[field]
             return
 
         field_split = field.split("__")
@@ -862,7 +868,7 @@ class FieldSelectQuery(AwaitableQuery):
                 field=field_split[0],
                 forwarded_fields="__".join(field_split[1:]),
             )
-            self.query._select_field(getattr(related_table, related_db_field).as_(return_as))
+            self.query._select_field(related_table[related_db_field].as_(return_as))
             return
 
         raise FieldError(f'Unknown field "{field}" for model "{self.model.__name__}"')
